@@ -1,4 +1,4 @@
-# Copyright 1998-2009, Paul Johnson (paul@pjcj.net)
+# Copyright 1998-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -26,7 +26,7 @@ my %Top_tag_order;
 
 BEGIN
 {
-  $VERSION = "1.16";
+  $VERSION = "1.17";
 
   $Tags =
   {
@@ -203,17 +203,32 @@ sub AUTOLOAD
     *$func = sub
     {
       my $self = shift;
-      my $r = $self->add_record(tag => $tag);
+      my ($arg, $val) = @_;
+      my $xref;
+      if (ref $arg)
+      {
+        $xref = $arg->{xref};
+      }
+      else
+      {
+        $val = $arg;
+      }
+      my $record = $self->add_record(tag => $tag, val => $val);
+      if (defined $val && $tag eq "NOTE")
+      {
+        $record->{value} = $val;
+      }
+      $xref = $tag eq "SUBM" ? "SUBM" : substr $tag, 0, 1
+        unless defined $xref;
       unless ($tag =~ /^(HEAD|TRLR)$/)
       {
-        my $x = @_ ? shift : $tag eq "SUBM" ? "SUBM" : substr $tag, 0, 1;
-        croak "Invalid xref $x requested in $func"
-          unless $x =~ /^[^\W\d_]+(\d*)$/;
-        $x = $self->next_xref($x) unless length $1;
-        $r->{xref} = $x;
-        $self->{xrefs}{$r->{xref}} = $r;
+        croak "Invalid xref $xref requested in $func"
+          unless $xref =~ /^[^\W\d_]+(\d*)$/;
+        $xref = $self->next_xref($xref) unless length $1;
+        $record->{xref} = $xref;
+        $self->{xrefs}{$xref} = $record;
       }
-      $r
+      $record
     };
   }
   else
@@ -231,10 +246,10 @@ sub AUTOLOAD
   goto &$func
 }
 
-use Gedcom::Grammar    1.16;
-use Gedcom::Individual 1.16;
-use Gedcom::Family     1.16;
-use Gedcom::Event      1.16;
+use Gedcom::Grammar    1.17;
+use Gedcom::Individual 1.17;
+use Gedcom::Family     1.17;
+use Gedcom::Event      1.17;
 
 sub new
 {
@@ -248,6 +263,7 @@ sub new
     read_only => 0,
     types     => {},
     xrefs     => {},
+    encoding  => "ansel",
     @_
   };
 
@@ -334,12 +350,12 @@ sub new
           $l2->add("ADDR", "http://www.pjcj.net");
           $l2 = $l1->add("DATA");
             $l3 = $l2->add("COPR",
-                           'Copyright 1998-2009, Paul Johnson (paul@pjcj.net)');
+                           'Copyright 1998-2012, Paul Johnson (paul@pjcj.net)');
         $l1 = $l0->add("NOTE", "");
       for (split /\n/, <<'EOH')
 This output was generated by Gedcom.pm.
-Gedcom.pm is Copyright 1999-2009, Paul Johnson (paul@pjcj.net)
-Version 1.16 - 24th April 2009
+Gedcom.pm is Copyright 1999-2012, Paul Johnson (paul@pjcj.net)
+Version 1.17 - 29th December 2012
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -353,7 +369,7 @@ EOH
         $l1->add("VERS", $self->{grammar}{version});
         $l1->add("FORM", "LINEAGE-LINKED");
       $l0->add("DATE", $date);
-      $l0->add("CHAR", "ANSEL");
+      $l0->add("CHAR", uc ($self->{encoding} || "ansel"));
       my $s = $r->get_record("subm");
       unless ($s)
       {
@@ -371,12 +387,20 @@ EOH
   $self
 }
 
+sub set_encoding
+{
+  my $self = shift;
+  ($self->{encoding}) = @_;
+}
+
 sub write
 {
   my $self  = shift;
   my $file  = shift or die "No filename specified";
   my $flush = shift;
   $self->{fh} = FileHandle->new($file, "w") or die "Can't open $file: $!";
+  binmode $self->{fh}, ":encoding(UTF-8)"
+    if $self->{encoding} eq "utf-8" && $] >= 5.8;
   $self->{record}->write($self->{fh}, -1, $flush);
   $self->{fh}->close or die "Can't close $file: $!";
 }
@@ -386,14 +410,16 @@ sub write_xml
   my $self = shift;
   my $file = shift or die "No filename specified";
   $self->{fh} = FileHandle->new($file, "w") or die "Can't open $file: $!";
+  binmode $self->{fh}, ":encoding(UTF-8)"
+    if $self->{encoding} eq "utf-8" && $] >= 5.8;
   $self->{fh}->print(<<'EOH');
 <?xml version="1.0" encoding="utf-8"?>
 
 <!--
 
 This output was generated by Gedcom.pm.
-Gedcom.pm is Copyright 1999-2009, Paul Johnson (paul@pjcj.net)
-Version 1.16 - 24th April 2009
+Gedcom.pm is Copyright 1999-2012, Paul Johnson (paul@pjcj.net)
+Version 1.17 - 29th December 2012
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -659,7 +685,7 @@ __END__
 
 Gedcom - a module to manipulate Gedcom genealogy files
 
-Version 1.16 - 24th April 2009
+Version 1.17 - 29th December 2012
 
 =head1 SYNOPSIS
 
@@ -667,7 +693,7 @@ Version 1.16 - 24th April 2009
 
   my $ged = Gedcom->new;
   my $ged = Gedcom->new($gedcom_file);
-  my $ged = Gedcom->new(grammar_version => 5.5,
+  my $ged = Gedcom->new(grammar_version => "5.5.1",
                         gedcom_file     => $gedcom_file,
                         read_only       => 1,
                         callback        => $cb);
@@ -681,6 +707,7 @@ Version 1.16 - 24th April 2009
   $ged->normalise_dates;
   my %xrefs = $ged->renumber;
   $ged->order;
+  $ged->set_encoding("utf-8");
   $ged->write($new_gedcom_file, $flush);
   $ged->write_xml($new_xml_file);
   my @individuals = $ged->individuals;
@@ -699,7 +726,7 @@ Version 1.16 - 24th April 2009
 
 =head1 DESCRIPTION
 
-Copyright 1998-2009, Paul Johnson (paul@pjcj.net)
+Copyright 1998-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -831,7 +858,7 @@ there is no value, as is the case for the birth record, then the record
 itself is returned.  If there is a value, but the record itself is
 required, then the get_record() function can be used.
 
-Information must be accesed through the Gedcom structure so, for
+Information must be accessed through the Gedcom structure so, for
 example, the birthdate is accessed via the date record from the birth
 record within an individual.
 
@@ -901,7 +928,7 @@ specified on the command line.
 
 I have not gone the whole hog with data encapsulation and such within
 this module.  Maybe I should have done.  Maybe I will.  For now though,
-the data is accessable though hash members.  This is partly because
+the data is accessible though hash members.  This is partly because
 having functions to do this is a little slow, especially on my old
 DECstation, and partly because of laziness again.  I'm not too sure
 whether this is good or bad laziness yet.  Time will tell no doubt.
@@ -937,7 +964,7 @@ See Gedcom::Record.pm for more details.
 
   my $ged = Gedcom->new($gedcom_file);
 
-  my $ged = Gedcom->new(grammar_version => 5.5,
+  my $ged = Gedcom->new(grammar_version => "5.5.1",
                         gedcom_file     => $gedcom_file,
                         read_only       => 1,
                         callback        => $cb);
@@ -952,11 +979,12 @@ supply a gedcom_file parameter then you will get an empty Gedcom object,
 empty that is apart from a few mandatory records.
 
 You may optionally pass grammar_version as the version number of the
-gedcom grammar you want to use.  At the moment only version 5.5 is
-available.  If you do not specify a grammar version, you may specify a
+gedcom grammar you want to use.  There are two versions available, 5.5
+and 5.5.1.  If you do not specify a grammar version, you may specify a
 grammar file as grammar_file.  Usually, you will do neither of these,
-and in this case the grammar version will default to the latest
-available version, currently 5.5.
+and in this case the grammar version will default to the latest full
+available version, currently 5.5.  5.5.1 is only a draft, but it is
+available if you specify it.
 
 The read_only parameter indicates that the Gedcom data structure will be
 used primarily for read_only operations.  In this mode the gedcom file
@@ -967,7 +995,7 @@ of the gedcom file needs to be read, for example to validate it, or to
 write it out in a different format, then this option should not be used.
 
 When using the read_only option an index file is kept which can also
-speed up operations.  It's usage should be transparant, but will require
+speed up operations.  It's usage should be transparent, but will require
 write access to the directory containing the gedcom file.  If you access
 individuals only by their xref (eg I20) then the index file will allow
 only the relevant parts of the gedcom file to be read.
@@ -997,6 +1025,17 @@ arguments:
 
 If the subroutine returns false, the operation is aborted.
 
+=head2 set_encoding
+
+  $ged->set_encoding("utf-8");
+
+Valid arguments are "ansel" and "utf-8".  Defaults to "ansel" but is set to
+"utf-8" if the gedcom data was read from a file which was deemed to contain
+UTF-8, either due to the presence of a BOM or as specified by a CHAR item.
+
+Set the encoding for the gedcom file.  Calling this directly doesn't alter the
+CHAR item, but does affect the way in which files are written.
+
 =head2 write
 
   $ged->write($new_gedcom_file, $flush);
@@ -1176,6 +1215,14 @@ Return the next available xref with the specified prefix.
 
 Create and return a new record of the specified type.
 
+Normally you will not want to pass any arguments to the function.  Those
+functions which have an xref (ie not header or trailer) accept an optional
+first argument { xref => $x } which will use $x as the xref rather than
+letting the module automatically choose the xref.
+
+add_note also accepts an optional second argument which is the text to be used
+on the first line of the note.
+
 =head2 get_record
 
        get_header
