@@ -1,4 +1,4 @@
-# Copyright 1998-2009, Paul Johnson (paul@pjcj.net)
+# Copyright 1998-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -13,10 +13,10 @@ require 5.005;
 
 package Gedcom::Family;
 
-use Gedcom::Record 1.16;
+use Gedcom::Record 1.17;
 
 use vars qw($VERSION @ISA);
-$VERSION = "1.16";
+$VERSION = "1.17";
 @ISA     = qw( Gedcom::Record );
 
 sub husband
@@ -112,7 +112,7 @@ __END__
 
 Gedcom::Family - a module to manipulate Gedcom families
 
-Version 1.16 - 24th April 2009
+Version 1.17 - 29th December 2012
 
 =head1 SYNOPSIS
 
@@ -155,7 +155,7 @@ None yet.
 Return a list of individuals from family $f.
 
 Each function, even those with a singular name such as husband(),
-returns a list of individuals holding that releation in $f.
+returns a list of individuals holding that relation in $f.
 
 =head2 number_of_children
 
@@ -173,7 +173,7 @@ counting.
 Add the specified individual to the family in the appropriate position.
 
 These functions also take care of the references from the individual
-back to the family, and are to be prefered to the low level addition
+back to the family, and are to be preferred to the low level addition
 functions which do not do this.
 
 =cut
