@@ -1,13 +1,13 @@
 #!/usr/local/bin/perl -w
 
-# Copyright 1999-2005, Paul Johnson (pjcj@cpan.org)
+# Copyright 1999-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
 # The latest version of this software should be available from my homepage:
 # http://www.pjcj.net
 
-# Version 1.15 - 3rd May 2005
+# Version 1.17 - 29th December 2012
 
 use strict;
 
@@ -16,11 +16,11 @@ require 5.005;
 package Basic;
 
 use vars qw($VERSION);
-$VERSION = "1.15";
+$VERSION = "1.17";
 
 use Test ();
 
-use Gedcom 1.15;
+use Gedcom 1.17;
 
 eval "use Date::Manip";
 Date_Init("DateFormat=UK") if $INC{"Date/Manip.pm"};
@@ -61,10 +61,10 @@ sub import
     ok $ged->validate;
 
     $ged->$resolve();
-#   ok $ged->validate;
+    ok $ged->validate;
 
     $ged->normalise_dates if $INC{"Date/Manip.pm"};
-#   ok $ged->validate;
+    ok $ged->validate;
 
     my $fams = 47;
     my $inds = 91;
@@ -76,17 +76,17 @@ sub import
     ok rins ($ged->families   ), i($inds + 2 .. $fams + $inds + 1);
 
     %xrefs = $ged->renumber;
-#   ok $ged->validate;
+    ok $ged->validate;
 
     $ged->$resolve();
-#   ok $ged->validate;
+    ok $ged->validate;
 
     ok $xrefs{INDI}, 91;
     ok $xrefs{FAM},  47;
     ok $xrefs{SUBM}, 1;
 
     $ged->order;
-#   ok $ged->validate;
+    ok $ged->validate;
 
     ok xrefs($ged->individuals), i(1 .. $inds);
     ok rins ($ged->individuals),
@@ -160,10 +160,10 @@ sub import
     ok rins($ged->resolve_xref($ind_xref)), "10";
 
     %xrefs = $ged->renumber(xrefs => [$ind_xref]);
-#   ok $ged->validate;
+    ok $ged->validate;
 
     $ged->$resolve();
-#   ok $ged->validate;
+    ok $ged->validate;
 
     ok $xrefs{INDI}, 91;
     ok $xrefs{FAM},  47;
@@ -240,9 +240,9 @@ sub import
        $i = $ged->get_individual("I83");
     my $n = $i->resolve($i->note)->full_value;
     ok $n, "Line 1\nLine 2";
-#   ok $ged->validate;
+    ok $ged->validate;
 
-    my $f1 = $gedcom_file . "1";
+    my $f1 = $gedcom_file . $$;
     $ged->write($f1);
     ok $ged->validate;
     ok -e $f1;
@@ -255,14 +255,14 @@ sub import
     ok unlink $f1;
   };
 
-  my $tests = 1492;
+  my $tests = 1501;
   my $grammar;
   if ($grammar = delete $args{create_grammar})
   {
     Test::plan tests => $tests + 3;
     system ($^X, ((-d "t") ? "." : "..") . "/parse_grammar", $grammar, 0.1);
     ok $?, 0;
-    ok -e "Gedcom/Grammar_0_1.pm";
+    ok -e "lib/Gedcom/Grammar_0_1.pm";
     $args{grammar_version} = 0.1;
   }
   else
@@ -270,18 +270,31 @@ sub import
     Test::plan tests => $tests;
   }
 
-  require Engine;
-  Engine->test(%args, subroutine => $basic_test);
+  my $g = _new_gedcom( \%args );
+  $basic_test->( $g, %args );
 
   if ($grammar)
   {
-    ok unlink ((-d "t") ? "." : "..") . "/Gedcom/Grammar_0_1.pm";
+    ok unlink ((-d "t") ? "." : "..") . "/lib/Gedcom/Grammar_0_1.pm";
   }
 }
 
+sub _new_gedcom {
+  my $args = shift;
+  $args->{gedcom_file} = (-d "t" ? "" : "../") . "royal.ged"
+    unless defined $args->{gedcom_file};
+  $args->{read_only} = 1
+    unless defined $args->{read_only};
+
+  my $ged = Gedcom->new(%$args);
+
+  return $ged;
+}
+
 __DATA__
 0 HEAD
 1   SOUR PAF 2.2
+2     VERS 2.2
 1   DEST PAF
 1   DATE Friday, 20th November 1992
 1   FILE ROYALS.GED
@@ -296,7 +309,7 @@ __DATA__
 2     CONC should use the original if you want royal genealogy.  Contact me
 2     CONC if you cannot locate the original.
 2     CONC
-2     CONC Paul Johnson (pjcj@cpan.org)
+2     CONC Paul Johnson (paul@pjcj.net)
 2     CONC
 2     CONC >> In a message to Cliff Manis (cmanis@csoftec.csf.com)
 2     CONC >> Denis Reid wrote the following:
